pygeodesy.deprecated.bases

Package pygeodesy :: Package deprecated :: Module bases |
[frames] | no frames]

# Module bases

DEPRECATED on 2021.02.10, use (INTERNAL) module pygeodesy.latlonBase instead.

Version: 25.05.12

Classes
| LatLonHeightBase DEPRECATED on 2021.02.10, use (INTERNAL) class pygeodesy.latlonBase.LatLonBase.

Functions
points2(points, closed=True, base=None, Error=<class 'pygeodesy.errors.PointsError'>) Check a path or polygon represented by points. |

Variables
| __all__ = `_ALL_DEPRECATED.deprecated_bases`

Function Details

### points2 (points, closed=True, base=None, Error=<class 'pygeodesy.errors.PointsError'>) |
Check a path or polygon represented by points. Arguments: `points` - The path or polygon points (`LatLon`[]) `closed` - Optionally, consider the polygon closed, ignoring any duplicate or closing final `points` (`bool`). `base` - Optionally, check all `points` against this base class, if `None` don't check. `Error` - Exception to raise (`ValueError`). Returns: A Points2Tuple`(number, points)` with the number of points and the points `list` or `tuple`. Raises: `PointsError` - Insufficient number of `points`. `TypeError` - Some `points` are not `base` compatible or composite `points`.